@@ -1,5 +1,5 @@
 package ExtUtils::Builder::Conf;
-$ExtUtils::Builder::Conf::VERSION = '0.032';
+$ExtUtils::Builder::Conf::VERSION = '0.033';
 use strict;
 use warnings;
 
@@ -17,7 +17,7 @@ sub fail {
 	die $message;
 }
 
-my @names = qw/include_dirs library_dirs libraries extra_compiler_flags extra_linker_flags/;
+my @names = qw/include_dirs library_dirs libraries extra_compiler_flags extra_linker_flags extra_sources extra_objects/;
 
 sub add_methods {
 	my ($self, $planner, %args) = @_;
@@ -140,6 +140,13 @@ sub add_methods {
 			}
 		}
 
+		if ($args{push_sources}) {
+			push @{ $self->{extra_sources} }, @{ $args{push_sources} };
+		}
+		if ($args{push_objects}) {
+			push @{ $self->{extra_objects} }, @{ $args{push_objects} };
+		}
+
 		return !!1;
 	});
 
@@ -236,7 +243,7 @@ ExtUtils::Builder::Conf - Configure-time utilities for using C headers, librarie
 
 =head1 VERSION
 
-version 0.032
+version 0.033
 
 =head1 SYNOPSIS
 
