@@ -1,5 +1,5 @@
 package ExtUtils::Builder::Linker::PE::MSVC;
-$ExtUtils::Builder::Linker::PE::MSVC::VERSION = '0.031';
+$ExtUtils::Builder::Linker::PE::MSVC::VERSION = '0.033';
 use strict;
 use warnings;
 
@@ -22,7 +22,7 @@ sub linker_flags {
 	push @ret, map { $self->new_argument(ranking => $_->{ranking}, value => [ "/libpath:$_->{value}" ]) } @{ $self->{library_dirs} };
 	push @ret, map { $self->new_argument(ranking => $_->{ranking}, value => [ "$_->{value}.lib" ]) } @{ $self->{libraries} };
 	push @ret, $self->new_argument(ranking => 50, value => [ @{$from} ]);
-	push @ret, $self->new_argument(ranking => 60, value => [ "/def:$opts{dl_file}" ]) if $self->export eq 'some' && defined $opts{dl_file};
+	push @ret, $self->new_argument(ranking => 60, value => [ "/def:$opts{dl_file}.def" ]) if $self->export eq 'some' && defined $opts{dl_file};
 	push @ret, $self->new_argument(ranking => 80, value => ["/OUT:$to"]);
 	# map_file, implib, def_file?…
 	return @ret;
